@@ -5,6 +5,7 @@ use utf8;
 package KUB::Request;
 
 use Xyzzy::Util qw(parse_bool);
+use KUB::Request::Error;
 
 use Xyzzy::Request -self;
 
@@ -56,8 +57,8 @@ field lang => sub {
 
 sub error {
 	my ($type, $exc, %args) = @_;
-	die $exc if ref $exc;
+	die $exc if UNIVERSAL::isa($exc, 'Xyzzy::Response');
 	warn $exc if $exc;
-	my $doc = new KUB::Error(req => $self, type => $type, args => \%args);
+	my $doc = new KUB::Request::Error(req => $self, type => $type, args => \%args);
 	return $doc->response;
 }
